terraform {
  required_providers {
    akamai = {
      source  = "akamai/akamai"
      version = ">= 6.5.0"
    }
  }
  required_version = ">= 1.0"
}

provider "akamai" {
  edgerc         = var.edgerc_path
  config_section = var.config_section
}

data "akamai_property_rules_template" "rules" {
  template_file = abspath("${path.module}/property-snippets/main.json")
  variables {
    name  = "edgeworker_id"
    value = akamai_edgeworker.geo_languagecookie.id
    type  = "string"
  }
}

# resource "akamai_edge_hostname" "akaudevops-com-edgekey-net" {
#   contract_id   = var.contract_id
#   group_id      = var.group_id
#   ip_behavior   = "IPV6_COMPLIANCE"
#   edge_hostname = "akaudevops.com.edgekey.net"
#   certificate   = 189619
# }

resource "akamai_property" "devops0caa-tflab" {
  name        = "devops0caa-tflab"
  contract_id = var.contract_id
  group_id    = var.group_id
  product_id  = "prd_SPM"
  hostnames {
    cname_from             = "devops0caatflab-test.akaudevops.com"
    cname_to               = "akaudevops.com.edgekey.net"
    cert_provisioning_type = "CPS_MANAGED"
  }
  hostnames {
    cname_from             = "devops0caatflab.akaudevops.com"
    cname_to               = "akaudevops.com.edgekey.net"
    cert_provisioning_type = "CPS_MANAGED"
  }
  rule_format = "latest"
  rules       = data.akamai_property_rules_template.rules.json
}

# NOTE: Be careful when removing this resource as you can disable traffic
resource "akamai_property_activation" "devops0caa-tflab-staging" {
  property_id                    = akamai_property.devops0caa-tflab.id
  contact                        = ["devops0caa@akaudevops.com"]
  version                        = akamai_property.devops0caa-tflab.latest_version
  network                        = "STAGING"
  note                           = "Terraform property creation lab"
  auto_acknowledge_rule_warnings = true
}

# NOTE: Be careful when removing this resource as you can disable traffic
#resource "akamai_property_activation" "devops0caa-tflab-production" {
#  property_id                    = akamai_property.devops0caa-tflab.id
#  contact                        = []
#  version                        = var.activate_latest_on_production ? akamai_property.devops0caa-tflab.latest_version : akamai_property.devops0caa-tflab.production_version
#  network                        = "PRODUCTION"
#  auto_acknowledge_rule_warnings = false
#}
